summaryrefslogtreecommitdiffstats
path: root/src/hardware_batteryCollection.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/hardware_batteryCollection.cpp')
-rw-r--r--src/hardware_batteryCollection.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/hardware_batteryCollection.cpp b/src/hardware_batteryCollection.cpp
index a9b00e4..0d3fe63 100644
--- a/src/hardware_batteryCollection.cpp
+++ b/src/hardware_batteryCollection.cpp
@@ -68,11 +68,11 @@ void BatteryCollection::initDefault() {
/*!
* This function refresh the information of the collection from the given
* batterylist.
* \param BatteryList QPtrList with battery objects
* \param force_level_recheck boolean with info if the the check for the current
* battery warning level should get forced
*/
-bool BatteryCollection::refreshInfo(QPtrList<Battery> BatteryList, bool force_level_recheck) {
+bool BatteryCollection::refreshInfo(TQPtrList<Battery> BatteryList, bool force_level_recheck) {
kdDebugFuncIn(trace);
int _charging_state = UNKNOWN_STATE;
@@ -203,13 +203,13 @@ bool BatteryCollection::refreshInfo(QPtrList<Battery> BatteryList, bool force_le
}
//! check if the given udi is already handled by this collection
-bool BatteryCollection::isBatteryHandled( QString udi ) {
- return udis.contains( udi );
+bool BatteryCollection::isBatteryHandled( TQString udi ) {
+ return udis.tqcontains( udi );
}
// ---> write private members SECTION : START <----
//! get the unit for charge level stuff
-QString BatteryCollection::getChargeLevelUnit() const {
+TQString BatteryCollection::getChargeLevelUnit() const {
return present_rate_unit;
}
@@ -68,11 +68,11 @@ void BatteryCollection::initDefault() {
* This function refresh the information of the collection from the given
* batterylist.
- * \param BatteryList QPtrList with battery objects
+ * \param BatteryList TQPtrList with battery objects
* \param force_level_recheck boolean with info if the the check for the current
* battery warning level should get forced